// Copyright 2003 David Hilvert <dhilvert@auricle.dyndns.org>, 
//                              <dhilvert@ugcs.caltech.edu>

/*  This file is part of the Anti-Lamenessing Engine.

    The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Anti-Lamenessing Engine; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*
 * Static data translation unit for classes treating scenes as
 * two-dimensional data.
 */

#include "d2.h"

namespace d2 {
	#include "d2/align.cc"
	#include "d2/trans_multi.cc"
	#include "d2/render.cc"
	#include "d2/image_rw.cc"
	#include "d2/image.cc"
	#include "d2/exposure/exposure.cc"
	#include "d2/vise_core.cc"
	#include "d2/tfile.cc"
}
